==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1SELinuxStrategyOptionsFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface ExtensionsV1beta1SELinuxStrategyOptionsFluent<A extends ExtensionsV1beta1SELinuxStrategyOptionsFluent<A>> extends Fluent<A>{


    public String getRule();
    public A withRule(String rule);
    public Boolean hasRule();
    
/**
 * This method has been deprecated, please use method buildSeLinuxOptions instead.
 * @return The buildable object.
 */
@Deprecated public V1SELinuxOptions getSeLinuxOptions();
    public V1SELinuxOptions buildSeLinuxOptions();
    public A withSeLinuxOptions(V1SELinuxOptions seLinuxOptions);
    public Boolean hasSeLinuxOptions();
    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptions();
    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptionsLike(V1SELinuxOptions item);
    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> editSeLinuxOptions();
    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptions();
    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptionsLike(V1SELinuxOptions item);

    public interface SeLinuxOptionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1SELinuxOptionsFluent<ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<N>>{

        
    public N and();    public N endSeLinuxOptions();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1SELinuxStrategyOptionsFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface ExtensionsV1beta1SELinuxStrategyOptionsFluent<A extends ExtensionsV1beta1SELinuxStrategyOptionsFluent<A>> extends Fluent<A>{


    public String getRule();
    public A withRule(String rule);
    public Boolean hasRule();
    public A withNewRule(String arg1);
    public A withNewRule(StringBuilder arg1);
    public A withNewRule(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSeLinuxOptions instead.
 * @return The buildable object.
 */
@Deprecated public V1SELinuxOptions getSeLinuxOptions();
    public V1SELinuxOptions buildSeLinuxOptions();
    public A withSeLinuxOptions(V1SELinuxOptions seLinuxOptions);
    public Boolean hasSeLinuxOptions();
    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptions();
    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptionsLike(V1SELinuxOptions item);
    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> editSeLinuxOptions();
    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptions();
    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptionsLike(V1SELinuxOptions item);

    public interface SeLinuxOptionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1SELinuxOptionsFluent<ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<N>>{

        
    public N and();    public N endSeLinuxOptions();
}


}
